@@ -18,34 +18,6 @@ from enum import Flag, auto
 import copy
 
 
-class ARMStandardsFlag(Flag):
-    """
-    This class stores a flag that is returned by
-    :ref:act.io.armfiles.check_arm_standards.
-
-    Attributes
-    ----------
-    OK : flag
-        This flag is set if the dataset conforms to ARM standards.
-    NO_DATASTREAM : flag
-        This flag is set if the dataset does not have a datastream
-        field.
-
-    Examples
-    --------
-    .. code-block:: python
-
-         my_flag = act.io.armfiles.ARMStandardsFlag(
-             act.io.armfiles.ARMStandardsFlag.OK)
-         assert my_flag.OK
-
-    """
-    OK = auto()
-    """ The dataset conforms to ARM standards. """
-    NO_DATASTREAM = auto()
-    """ The dataset does not have a datastream field. """
-
-
 def read_netcdf(filenames, concat_dim='time', return_None=False,
                 combine='by_coords', use_cftime=True, cftime_to_datetime64=True,
                 **kwargs):
@@ -218,7 +190,7 @@ def read_netcdf(filenames, concat_dim='time', return_None=False,
 
     # Ensure that we have _datastream set whether or no there's
     # a datastream attribute already.
-    if is_arm_file_flag.NO_DATASTREAM is True:
+    if is_arm_file_flag == 0:
         arm_ds.attrs['_datastream'] = "act_datastream"
     else:
         arm_ds.attrs['_datastream'] = arm_ds.attrs['datastream']
@@ -239,17 +211,14 @@ def check_arm_standards(ds):
 
     Returns
     -------
-    flag : ARMStandardsFlag
+    flag : int
         The flag corresponding to whether or not the file conforms
-        to ARM standards.
+        to ARM standards. Bit packed, so 0 for no, 1 for yes
 
     """
-    the_flag = ARMStandardsFlag(ARMStandardsFlag.OK)
-    the_flag.NO_DATASTREAM = False
-    the_flag.OK = True
+    the_flag = (1 << 0)
     if 'datastream' not in ds.attrs.keys():
-        the_flag.OK = False
-        the_flag.NO_DATASTREAM = True
+        the_flag = 0
 
     return the_flag
 
@@ -421,6 +390,12 @@ class WriteDataset(object):
         **kwargs : keywords
             Keywords to pass through to Dataset.to_netcdf()
 
+        Examples
+        --------
+        .. code-block:: python
+
+        ds_object.write.write_netcdf(path='output.nc')
+
         """
 
         encoding = {}
@@ -439,12 +414,15 @@ class WriteDataset(object):
                 if 'standard_name' not in write_obj[var_name].attrs.keys():
                     continue
                 for attr_name in check_atts:
-                    if isinstance(write_obj[var_name].attrs[attr_name], (list, tuple)):
-                        att_values = write_obj[var_name].attrs[attr_name]
-                        for ii, att_value in enumerate(att_values):
-                            att_values[ii] = att_value.replace(' ', join_char)
+                    try:
+                        if isinstance(write_obj[var_name].attrs[attr_name], (list, tuple)):
+                            att_values = write_obj[var_name].attrs[attr_name]
+                            for ii, att_value in enumerate(att_values):
+                                att_values[ii] = att_value.replace(' ', join_char)
 
-                        write_obj[var_name].attrs[attr_name] = ' '.join(att_values)
+                            write_obj[var_name].attrs[attr_name] = ' '.join(att_values)
+                    except KeyError:
+                        pass
 
                 # Tell .to_netcdf() to not add a _FillValue attribute for
                 # quality control variables.
