@@ -21,6 +21,7 @@ be used for testing ACT.
     EXAMPLE_ANL_CSV
     EXAMPLE_VISST
     EXAMPLE_DLPPI
+    EXAMPLE_DLPPI_MULTI
     EXAMPLE_EBBR1
     EXAMPLE_EBBR2
     EXAMPLE_BRS
@@ -28,6 +29,8 @@ be used for testing ACT.
     EXAMPLE_MFRSR
     EXAMPLE_SURFSPECALB1MLAWER
     EXAMPLE_SIGMA_MPLV5
+    EXAMPLE_CO2FLX4M
+    EXAMPLE_SIRS
 """
 import os
 
@@ -56,6 +59,7 @@ EXAMPLE_NAV = os.path.join(DATA_PATH,
 EXAMPLE_AOSMET = os.path.join(DATA_PATH,
                               'maraosmetM1.a1.20180201.000000.nc')
 EXAMPLE_DLPPI = os.path.join(DATA_PATH, 'sgpdlppiC1.b1.20191015.120023.cdf')
+EXAMPLE_DLPPI_MULTI = os.path.join(DATA_PATH, 'sgpdlppiC1.b1.20191015.*.cdf')
 EXAMPLE_EBBR1 = os.path.join(DATA_PATH, 'sgp30ebbrE32.b1.20191125.000000.nc')
 EXAMPLE_EBBR2 = os.path.join(DATA_PATH, 'sgp30ebbrE32.b1.20191130.000000.nc')
 EXAMPLE_BRS = os.path.join(DATA_PATH, 'sgpbrsC1.b1.20190705.000000.cdf')
@@ -65,3 +69,6 @@ EXAMPLE_MFRSR = os.path.join(DATA_PATH, 'sgpmfrsr7nchE38.b1.20190514.180000.nc')
 EXAMPLE_SURFSPECALB1MLAWER = os.path.join(
     DATA_PATH, 'nsasurfspecalb1mlawerC1.c1.20160609.080000.nc')
 EXAMPLE_SIGMA_MPLV5 = os.path.join(DATA_PATH, '201509021500.bin')
+EXAMPLE_RL1 = os.path.join(DATA_PATH, 'sgprlC1.a0.20160131.000000.nc')
+EXAMPLE_CO2FLX4M = os.path.join(DATA_PATH, 'sgpco2flx4mC1.b1.20201007.001500.nc')
+EXAMPLE_SIRS = os.path.join(DATA_PATH, 'sgpsirsE13.b1.20190101.000000.cdf')
